# [2.5.6](https://github.com/seriaati/enka-py/compare/v2.5.5..v2.5.6) - 2025-05-28

## Documentation

- Change comment a bit - ([2bc9168](https://github.com/seriaati/enka-py/commit/2bc9168dfbe8ea8d269f6b773471c345caa44ff2))

## Refactoring

- Refactor ZZZ stat calc logic ([#110](https://github.com/seriaati/enka-py/issues/110)) - ([28d47b5](https://github.com/seriaati/enka-py/commit/28d47b561b7a9285e10254401898aee3e12934ed))

